@@ -1,6 +1,6 @@
 """Test getting current user."""
+# pylint: disable=no-self-use
 import json
-import os
 from subprocess import check_output
 
 from integration_tests.test_commands.test_commands import Commands
@@ -13,19 +13,14 @@ class TestRunAWS(Commands):
 
     def init(self):
         """Initialize test."""
-        pass  # pylint: disable=unnecessary-pass
 
     def run(self):
         """Run test."""
         response = check_output(
-            ['runway',
-             'run-aws',
-             'sts',
-             'get-caller-identity']
+            ["runway", "run-aws", "sts", "get-caller-identity"]
         ).decode()
         data = json.loads(response)
-        assert 'Arn' in data, 'response has no Arn property'
+        assert "Arn" in data, "response has no Arn property"
 
     def teardown(self):
         """Teardown any created resources."""
-        pass  # pylint: disable=unnecessary-pass
