@@ -22,13 +22,13 @@ def run_command(cmd_list, env_vars=None):
 def import_tests(logger, path, pattern, use_abs=True):
     """Find and import all tests from a given path."""
     logger.info('Loading tests from "%s" with pattern: "%s"', path, pattern)
-    tests = glob.glob(os.path.join(path, '{}.py'.format(pattern)))
+    tests = glob.glob(os.path.join(path, "{}.py".format(pattern)))
     for test in tests:
         relpath = os.path.relpath(test)[:-3]
-        test_name = relpath.replace(os.path.sep, '.')
+        test_name = relpath.replace(os.path.sep, ".")
         logger.info('Found test: "%s". Attempting to import...', test_name)
         if use_abs:
-            final_path = os.path.abspath(relpath).split('/runway/')[1].replace('/', '.')
+            final_path = os.path.abspath(relpath).split("/runway/")[1].replace("/", ".")
         else:
             final_path = relpath
         try:
@@ -46,40 +46,51 @@ def execute_tests(tests, logger):
         test_name = test.__class__.__name__
 
         if not issubclass(test.__class__, IntegrationTest):
-            logger.error('%s does not inherit from "IntegrationTest", skipping...',
-                         test_name)
+            logger.error(
+                '%s does not inherit from "IntegrationTest", skipping...', test_name
+            )
             continue
 
-        logger.info('==========================Executing test "%s"' +
-                    '==========================', test_name)
+        logger.info(
+            '==========================Executing test "%s"'
+            + "==========================",
+            test_name,
+        )
 
         try:
             logger.info('Executing "run" for "%s"...', test_name)
             test.run()
-            results[test_name] = 'Success'
+            results[test_name] = "Success"
         except AssertionError as assert_err:
             logger.error('AssertionError: "%s"', assert_err)
             err_count += 1
-            results[test_name] = 'Failed'
+            results[test_name] = "Failed"
         finally:
             try:
                 logger.info('Executing "teardown" for "%s"...', test_name)
                 test.teardown()
             except BaseException as err:
-                logger.error("Teardown failed for test \"%s\". "
-                             "Some resources may need to be cleaned up manually.",
-                             test_name)
+                logger.error(
+                    'Teardown failed for test "%s". '
+                    "Some resources may need to be cleaned up manually.",
+                    test_name,
+                )
                 logger.error(err)
 
-    tbl = PrettyTable(['Test Name', 'Result'])
-    tbl.align['Test Name'] = 'l'
+    tbl = PrettyTable(["Test Name", "Result"])
+    tbl.align["Test Name"] = "l"
 
     for key, value in results.items():
         tbl.add_row([key, value])
 
-    logger.info('\r\n==========================Test Results==========================' +
-                '\r\n' + str(tbl) + '\r\n%s out of %s Tests Passed',
-                (len(tests) - err_count), len(tests))
+    logger.info(
+        "\r\n==========================Test Results=========================="
+        + "\r\n"
+        + str(tbl)
+        + "\r\n%s out of %s Tests Passed",
+        (len(tests) - err_count),
+        len(tests),
+    )
     return err_count
 
 
@@ -88,7 +99,7 @@ def copy_file(src, dest):
     if os.path.isfile(src):
         shutil.copy(src, dest)
     else:
-        print('copy: File not found: %s' % src)
+        print("copy: File not found: %s" % src)
 
 
 def copy_dir(src, dest):
