@@ -21,11 +21,7 @@ if TYPE_CHECKING:
 
 LOGGER = _logging.getLogger(__name__)
 
-__all__ = [
-    'Runway',
-    'components',
-    'providers'
-]
+__all__ = ["Runway", "components", "providers"]
 
 
 class Runway(object):
@@ -59,8 +55,9 @@ class Runway(object):
                 all deployments in the config will be run.
 
         """
-        self.__run_action('deploy', deployments if deployments is not None else
-                          self.deployments)
+        self.__run_action(
+            "deploy", deployments if deployments is not None else self.deployments
+        )
 
     def destroy(self, deployments=None):
         # type: (Optional[List[DeploymentDefinition]]) -> None
@@ -71,8 +68,12 @@ class Runway(object):
                 all deployments in the config will be run in reverse.
 
         """
-        self.__run_action('destroy', deployments if deployments is not None else
-                          self.reverse_deployments(self.deployments))
+        self.__run_action(
+            "destroy",
+            deployments
+            if deployments is not None
+            else self.reverse_deployments(self.deployments),
+        )
         if not deployments:
             # return config attribute to original state
             self.reverse_deployments(self.deployments)
@@ -91,9 +92,9 @@ class Runway(object):
         deployments = deployments or self.deployments
         result = {}
         for deployment in deployments:
-            obj = components.Deployment(context=self.ctx,
-                                        definition=deployment,
-                                        variables=self.variables)
+            obj = components.Deployment(
+                context=self.ctx, definition=deployment, variables=self.variables
+            )
             result.update(obj.env_vars_config)
         return result
 
@@ -106,8 +107,9 @@ class Runway(object):
                 all deployments in the config will be run.
 
         """
-        self.__run_action('plan', deployments if deployments is not None else
-                          self.deployments)
+        self.__run_action(
+            "plan", deployments if deployments is not None else self.deployments
+        )
 
     @staticmethod
     def reverse_deployments(deployments):
@@ -130,37 +132,49 @@ class Runway(object):
     def test(self):
         """Run tests defined in the config."""
         if not self.tests:
-            LOGGER.error('no tests defined in runway.yml')
-            LOGGER.error('to learn more about using Runway to run tests, '
-                         'visit %s/page/defining_tests.html', DOC_SITE)
-            LOGGER.error('Example test:\n%s', _yaml.dump({
-                'tests': [{'name': 'example-test',
-                           'type': 'script',
-                           'required': True,
-                           'args': {'commands': ['echo "Success!"']}}]
-            }, Dumper=_YamlDumper))
+            LOGGER.error("no tests defined in runway.yml")
+            LOGGER.error(
+                "to learn more about using Runway to run tests, visit "
+                "%s/page/defining_tests.html",
+                DOC_SITE,
+            )
+            LOGGER.error(
+                "Example test:\n%s",
+                _yaml.dump(
+                    {
+                        "tests": [
+                            {
+                                "name": "example-test",
+                                "type": "script",
+                                "required": True,
+                                "args": {"commands": ['echo "Success!"']},
+                            }
+                        ]
+                    },
+                    Dumper=_YamlDumper,
+                ),
+            )
             _sys.exit(1)
-        self.ctx.command = 'test'
+        self.ctx.command = "test"
 
         failed_tests = []
 
-        LOGGER.info('found %i test(s)', len(self.tests))
+        LOGGER.info("found %i test(s)", len(self.tests))
         for tst in self.tests:
             tst.resolve(self.ctx, variables=self.variables)
             logger = _PrefixAdaptor(tst.name, LOGGER)
-            logger.notice('running test (in progress)')
+            logger.notice("running test (in progress)")
             try:
                 handler = _TEST_HANDLERS[tst.type]
             except KeyError:
-                logger.error('unable to find handler of '
-                             'type "%s"', tst.type)
+                logger.error('unable to find handler of type "%s"', tst.type)
                 if tst.required:
                     _sys.exit(1)
                 failed_tests.append(tst.name)
                 continue
             try:
                 handler.handle(tst.name, tst.args)
-                logger.success('running test (pass)')
+                logger.success("running test (pass)")
             except (Exception, SystemExit) as err:  # pylint: disable=broad-except
                 # for lack of an easy, better way to do this atm, assume
                 # SystemExits are due to a test failure and the failure reason
@@ -170,44 +184,40 @@ class Runway(object):
                     _traceback.print_exc()
                 elif err.code == 0:
                     continue  # tests with zero exit code don't indicate failure
-                logger.error('running test (fail)')
+                logger.error("running test (fail)")
                 if tst.required:
-                    logger.error('test required; the remaining '
-                                 'tests have been skipped')
+                    logger.error("test required; the remaining tests have been skipped")
                     _sys.exit(1)
                 failed_tests.append(tst.name)
         if failed_tests:
-            LOGGER.error('the following tests failed: %s',
-                         ', '.join(failed_tests))
+            LOGGER.error("the following tests failed: %s", ", ".join(failed_tests))
             _sys.exit(1)
-        LOGGER.success('all tests passed')
+        LOGGER.success("all tests passed")
 
     def __assert_config_version(self):
         """Assert the config supports this version of Runway."""
         if __version__ in self.required_version:
             LOGGER.debug(
-                'current Runway version "%s" matches "%s" required by '
-                'this config file',
+                'current Runway version "%s" matches "%s" required by this config file',
                 __version__,
-                self.required_version
+                self.required_version,
             )
             return
-        if __version__.startswith('0.') and 'dev' in __version__:
+        if __version__.startswith("0.") and "dev" in __version__:
             LOGGER.warning(
-                'Runway is being used from a shallow clone of the repo; '
-                'config version will not be enforced as version cannot '
-                'be determined')
+                "Runway is being used from a shallow clone of the repo; "
+                "config version will not be enforced as version cannot be determined"
+            )
             return
         LOGGER.error(
-            'current Runway version "%s" does not match "%s" '
-            'required by this config file',
+            'current Runway version "%s" does not match "%s" required by this config file',
             __version__,
-            self.required_version
+            self.required_version,
         )
         _sys.exit(1)
 
     def __run_action(self, action, deployments):
-        # type: (Optional[List[DeploymentDefinition]]) -> None
+        # type: (str, Optional[List[DeploymentDefinition]]) -> None
         """Run an action on a list of deployments.
 
         Args:
@@ -216,8 +226,10 @@ class Runway(object):
 
         """
         self.ctx.command = action
-        components.Deployment.run_list(action=action,
-                                       context=self.ctx,
-                                       deployments=deployments,
-                                       future=self.future,
-                                       variables=self.variables)
+        components.Deployment.run_list(
+            action=action,
+            context=self.ctx,
+            deployments=deployments,
+            future=self.future,
+            variables=self.variables,
+        )
