@@ -6,7 +6,7 @@ distribution url + callback url paths.
 """
 # pylint: disable=unused-argument
 import logging
-from typing import TYPE_CHECKING, Any, Dict, Optional  # noqa pylint: disable=W
+from typing import TYPE_CHECKING, Any, Dict, List, Optional  # noqa pylint: disable=W
 
 if TYPE_CHECKING:
     from ....cfngin.context import Context  # pylint: disable=W
@@ -15,6 +15,15 @@ if TYPE_CHECKING:
 LOGGER = logging.getLogger(__name__)
 
 
+def get_redirect_uris(domains, redirect_path_sign_in, redirect_path_sign_out):
+    # type: (List[str], str, str) -> Dict[str, Any]
+    """Create dict of redirect URIs for AppClient."""
+    return {
+        "sign_in": ["%s%s" % (domain, redirect_path_sign_in) for domain in domains],
+        "sign_out": ["%s%s" % (domain, redirect_path_sign_out) for domain in domains],
+    }
+
+
 def update(context, provider, **kwargs):
     # type: (Context, BaseProvider, Optional[Dict[str, Any]]) -> bool
     """Update the callback urls for the User Pool Client.
@@ -46,14 +55,11 @@ def update(context, provider, **kwargs):
     ]
 
     # Create a list of all domains with their redirect paths
-    redirect_uris_sign_in = [
-        "%s%s" % (domain, kwargs["redirect_path_sign_in"])
-        for domain in redirect_domains
-    ]
-    redirect_uris_sign_out = [
-        "%s%s" % (domain, kwargs["redirect_path_sign_out"])
-        for domain in redirect_domains
-    ]
+    redirect_uris = get_redirect_uris(
+        redirect_domains,
+        kwargs["redirect_path_sign_in"],
+        kwargs["redirect_path_sign_out"],
+    )
     # Update the user pool client
     try:
         cognito_client.update_user_pool_client(
@@ -62,8 +68,8 @@ def update(context, provider, **kwargs):
             SupportedIdentityProviders=kwargs["supported_identity_providers"],
             AllowedOAuthFlowsUserPoolClient=True,
             ClientId=kwargs["client_id"],
-            CallbackURLs=redirect_uris_sign_in,
-            LogoutURLs=redirect_uris_sign_out,
+            CallbackURLs=redirect_uris["sign_in"],
+            LogoutURLs=redirect_uris["sign_out"],
             UserPoolId=context.hook_data["aae_user_pool_id_retriever"]["id"],
         )
         return True
