@@ -3,7 +3,7 @@ import logging
 import os
 import sys
 import tempfile
-from typing import Any, Dict, List, Union  # pylint: disable=unused-import
+from typing import Any, Dict  # pylint: disable=unused-import
 
 import yaml
 
@@ -62,6 +62,7 @@ class StaticSite(RunwayModule):
                 # Auth@Edge warning about subsequent deploys
                 if (
                     self.parameters.get("staticsite_auth_at_edge", False)
+                    and not self.parameters.get("staticsite_aliases", False)
                     and self.context.is_interactive
                 ):
                     self.logger.warning(
@@ -97,8 +98,15 @@ class StaticSite(RunwayModule):
         module_dir = self._create_module_directory()
         self._create_dependencies_yaml(module_dir)
         self._create_staticsite_yaml(module_dir)
-        # Don't destroy with the other stacks
-        if command != "destroy" and (
+
+        # Earlier Runway versions included a CFN stack with a state machine
+        # that attempted to automatically clean up the orphaned Lambda@Edge
+        # functions. This was found to be unreliable and has been removed.
+        # For a period of time (e.g. until the next major release) leaving this
+        # in to automatically delete the stack. Not a major priority to have
+        # Runway delete the old `-cleanup` stack, as the resources in it don't
+        # have any costs when unused.
+        if command == "destroy" and (
             self.parameters.get("staticsite_auth_at_edge")
             or self.parameters.get("staticsite_rewrite_index_index")
         ):
@@ -131,20 +139,25 @@ class StaticSite(RunwayModule):
         ]
 
         if self.parameters.get("staticsite_auth_at_edge", False):
-            # Retrieve the appropriate callback urls from the User Pool Client
-            pre_build = [
-                {
-                    "path": "runway.hooks.staticsite.auth_at_edge.callback_url_retriever.get",
-                    "required": True,
-                    "data_key": "aae_callback_url_retriever",
-                    "args": {
-                        "user_pool_arn": self.parameters.get(
-                            "staticsite_user_pool_arn", ""
-                        ),
-                        "stack_name": "${namespace}-%s-dependencies" % self.name,
-                    },
-                }
-            ]
+            if not self.parameters.get("staticsite_aliases"):
+                # Retrieve the appropriate callback urls from the User Pool Client
+                pre_build.append(
+                    {
+                        "path": "runway.hooks.staticsite.auth_at_edge.callback_url_retriever.get",
+                        "required": True,
+                        "data_key": "aae_callback_url_retriever",
+                        "args": {
+                            "user_pool_arn": self.parameters.get(
+                                "staticsite_user_pool_arn", ""
+                            ),
+                            "aliases": self.parameters.get("staticsite_aliases", ""),
+                            "additional_callback_domains": self.parameters.get(
+                                "staticsite_additional_callback_domains", ""
+                            ),
+                            "stack_name": "${namespace}-%s-dependencies" % self.name,
+                        },
+                    }
+                )
 
             if self.parameters.get("staticsite_create_user_pool"):
                 # Retrieve the user pool id
@@ -257,19 +270,11 @@ class StaticSite(RunwayModule):
         if self.parameters.get(
             "staticsite_rewrite_directory_index"
         ) or self.parameters.get("staticsite_auth_at_edge"):
-            replicated_function_vars = self._get_replicated_function_variables()
-            replicated_function_vars.update(
-                {
-                    "state_machine_arn": "${rxref %s-cleanup::"
-                    "ReplicatedFunctionRemoverStateMachineArn}" % (self.name),
-                }
-            )
             pre_destroy.append(
                 {
-                    "path": "runway.hooks.staticsite.cleanup.execute",
-                    "required": True,
-                    "data_key": "cleanup",
-                    "args": replicated_function_vars,
+                    "path": "runway.hooks.staticsite.cleanup.warn",
+                    "required": False,
+                    "args": {"stack_relative_name": self.name},
                 }
             )
 
@@ -307,17 +312,18 @@ class StaticSite(RunwayModule):
                     "args": self._get_lambda_config_variables(site_stack_variables),
                 }
             )
-            post_build.insert(
-                0,
-                {
-                    "path": "runway.hooks.staticsite.auth_at_edge.client_updater.update",
-                    "required": True,
-                    "data_key": "client_updater",
-                    "args": self._get_client_updater_variables(
-                        self.name, site_stack_variables
-                    ),
-                },
-            )
+            if not self.parameters.get("staticsite_aliases"):
+                post_build.insert(
+                    0,
+                    {
+                        "path": "runway.hooks.staticsite.auth_at_edge.client_updater.update",
+                        "required": True,
+                        "data_key": "client_updater",
+                        "args": self._get_client_updater_variables(
+                            self.name, site_stack_variables
+                        ),
+                    },
+                )
 
         if self.parameters.get("staticsite_role_boundary_arn", False):
             site_stack_variables["RoleBoundaryArn"] = self.parameters[
@@ -352,20 +358,15 @@ class StaticSite(RunwayModule):
         )
 
     def _create_cleanup_yaml(self, module_dir):
-        replicated_function_vars = self._get_replicated_function_variables()
-        if self.parameters.get("staticsite_role_boundary_arn", False):
-            replicated_function_vars["RoleBoundaryArn"] = self.parameters.pop(
-                "staticsite_role_boundary_arn"
-            )
-
         content = {
             "namespace": "${namespace}",
             "cfngin_bucket": "",
             "stacks": {
                 "%s-cleanup"
                 % self.name: {
-                    "class_path": "runway.blueprints.staticsite.cleanup.Cleanup",
-                    "variables": replicated_function_vars,
+                    "template_path": os.path.join(
+                        tempfile.gettempdir(), "thisfileisnotused.yaml"
+                    ),
                 }
             },
         }
@@ -376,32 +377,6 @@ class StaticSite(RunwayModule):
             "created 03-cleanup.yaml:\n%s", yaml.dump(content, Dumper=YamlDumper)
         )
 
-    def _get_replicated_function_variables(self):
-        replicated_function_vars = {
-            "stack_name": "${namespace}-%s-cleanup" % self.name,
-            "function_arns": [],
-            "DisableCloudFront": self.parameters.get("staticsite_cf_disable", False),
-        }  # type: Dict[str, Union[str, List[str]]]
-
-        if self.parameters.get("staticsite_rewrite_directory_index"):
-            replicated_function_vars["function_arns"].append(
-                "${rxref %s::LambdaCFDirectoryIndexRewriteArn}" % self.name
-            )
-
-        if self.parameters.get("staticsite_auth_at_edge"):
-            for lamb in [
-                "CheckAuth",
-                "HttpHeaders",
-                "ParseAuth",
-                "RefreshAuth",
-                "SignOut",
-            ]:
-                replicated_function_vars["function_arns"].append(
-                    "${rxref %s::Lambda%sArn}" % (self.name, lamb)
-                )
-
-        return replicated_function_vars
-
     def _get_site_stack_variables(self):
         site_stack_variables = {
             "Aliases": [],
@@ -452,9 +427,6 @@ class StaticSite(RunwayModule):
             site_stack_variables["HttpHeaders"] = self._get_http_headers()
             site_stack_variables["CookieSettings"] = self._get_cookie_settings()
             site_stack_variables["OAuthScopes"] = self._get_oauth_scopes()
-            site_stack_variables[
-                "SupportedIdentityProviders"
-            ] = self._get_supported_identity_providers()
         else:
             # If lambda_function_associations or custom_error_responses defined,
             # add to stack config. Only if not using Auth@Edge
@@ -512,9 +484,30 @@ class StaticSite(RunwayModule):
             self._ensure_auth_at_edge_requirements()
 
             variables.update(
-                {"AuthAtEdge": self.parameters.get("staticsite_auth_at_edge", False)}
+                {
+                    "AuthAtEdge": self.parameters.get("staticsite_auth_at_edge", False),
+                    "SupportedIdentityProviders": self._get_supported_identity_providers(),
+                    "RedirectPathSignIn": (
+                        "${default staticsite_redirect_path_sign_in::/parseauth}"
+                    ),
+                    "RedirectPathSignOut": (
+                        "${default staticsite_redirect_path_sign_out::/}"
+                    ),
+                }
             )
 
+            if self.parameters.get("staticsite_aliases"):
+                variables.update(
+                    {"Aliases": self.parameters.get("staticsite_aliases").split(",")}
+                )
+            if self.parameters.get("staticsite_additional_redirect_domains"):
+                variables.update(
+                    {
+                        "AdditionalRedirectDomains": self.parameters.get(
+                            "staticsite_additional_redirect_domains"
+                        ).split(",")
+                    }
+                )
             if self.parameters.get("staticsite_create_user_pool", False):
                 variables.update(
                     {
